@@ -32,7 +32,7 @@ check.mdsj <-function(ask=TRUE){
     mdsj.path <- file.path(path.package('ndtv'),'java/mdsj.jar')
     mdsj.dir <- file.path(path.package('ndtv'),'java/')
     if(!file.exists(mdsj.path)){
-      message("The MDSJ Java library does not appear to be installed. The ndtv package can use MDSJ to provide a fast accurate layout algorithm. It can be downloaded from http://www.inf.uni-konstanz.de/algo/software/mdsj/")
+      message("The MDSJ Java library does not appear to be installed. The ndtv package can use MDSJ to provide a fast accurate layout algorithm. It can be downloaded from http://algo.uni-konstanz.de/software/mdsj/")
       # ask user if the want to download
       #  how will this work during automated test?
       # "In non-interactive use the result is as if the response was RETURN and the value is ""."
@@ -72,12 +72,12 @@ install.mdsj <-function(install.path){
    stop('Unable to install MDSJ because the package path ',install.path,'does not appear to have write permissions')
  }
  # download file
- mdsjURL<-'http://www.inf.uni-konstanz.de/algo/software/mdsj/mdsj.jar'
+ mdsjURL<-'http://algo.uni-konstanz.de/software/mdsj/mdsj.jar'
  message('installing MDSJ to directory ',install.path)
  download.file(url=mdsjURL,destfile=file.path(install.path,'mdsj.jar'),mode='wb')
  if (file.exists(file.path(install.path,'mdsj.jar'))){
    #print non-comercial use warning
-   message("MDSJ is a free Java library for Multidimensional Scaling (MDS).\n It is a free, non-graphical, self-contained, lightweight implementation of basic MDS algorithms and intended to be used both as a standalone application and as a building block in Java based data analysis and visualization software. \n\n CITATION: Algorithmics Group. MDSJ: Java Library for Multidimensional Scaling (Version 0.2). Available at http://www.inf.uni-konstanz.de/algo/software/mdsj/. University of Konstanz, 2009. \n\n USE RESTRICTIONS: Creative Commons License 'by-nc-sa' 3.0.\n" )
+   message("MDSJ is a free Java library for Multidimensional Scaling (MDS).\n It is a free, non-graphical, self-contained, lightweight implementation of basic MDS algorithms and intended to be used both as a standalone application and as a building block in Java based data analysis and visualization software. \n\n CITATION: Algorithmics Group. MDSJ: Java Library for Multidimensional Scaling (Version 0.2). Available at http://algo.uni-konstanz.de/software/mdsj/. University of Konstanz, 2009. \n\n USE RESTRICTIONS: Creative Commons License 'by-nc-sa' 3.0.\n" )
  }
  
 }
