@@ -34,14 +34,14 @@ layout.center <- function(coords, xlim,ylim){
 # helper function to normalize coords in range (-1,1)
 layout.normalize <-function(coords,keep.aspect.ratio=TRUE){
   # translate
-  coords[,1]<-coords[,1]-min(coords[,1])
-  coords[,2]<-coords[,2]-min(coords[,2])
+  coords[,1]<-coords[,1]-min(coords[,1],na.rm = TRUE)
+  coords[,2]<-coords[,2]-min(coords[,2],na.rm = TRUE)
   # normalize to 1.0
   if (keep.aspect.ratio){
-    coords<-coords/(max(coords)/2)
+    coords<-coords/(max(coords,na.rm = TRUE)/2)
   } else {
-    coords[,1]<-coords[,1]/(max(coords[,1])/2)
-    coords[,2]<-coords[,2]/(max(coords[,2])/2)
+    coords[,1]<-coords[,1]/(max(coords[,1],na.rm = TRUE)/2)
+    coords[,2]<-coords[,2]/(max(coords[,2],na.rm = TRUE)/2)
   }
   # shift to center
   coords<-coords-1
